Cheshire3 Objects: ResultSetStore

|  | ## Cheshire3 Objects: Result Set Store

Description

A persistent storage mechanism for result sets.

Implementations

- recordStore.BdbResultSetStore
  The recommended implementation, it stores the terms in BerkeleyDB stores against UUIDs.

API

Function | Parameters | Returns | Description
--- | --- | --- | ---
__init__ | config, parent |  |
create_resultSet | session, ?resultSet |  | Generate a UUID for a result set, and if given, store it.
store_resultSet | session, resultSet |  | Store the result set
delete_resultSet | session, uuid |  | Delete the given result set
fetch_resultSet | session, uuid |  | Return the given result set
fetch_resultSetList | session |  | Return list of result set uuids present in the store
clean | session |  | Delete any result sets that have expired (according to the configuration)